Upgrading from dnstli 2.x.x to dnstli 3.0.0
===========================================

See [README.md] section `JSON web tokens, OAuth 2.0` if you
use the `web` or new `oauth` authentication methods. Prior configurations for
the `web` authentication method will no longer function.

You should remove the following obsolete `cookie_hmac_secret` key from
your configuration file. It has been obsoleted.

See the section `Cross-Origin Resource Sharing` regarding setting the
`cors_origin` configuration option.

Upgrading from an earlier version to dnstli 3.0.0
=================================================

`dnstli` 3.0.0 contains support for running under the [uWSGI application
server]. Previous versions of `dnstli` used an older application server that
used the SCGI protocol to communicate with the frontend nginx server. These
older versions used a per-process worker model and were limited to a
relatively low number of concurrent lookups.

While the uWSGI application server supports the older SCGI protocol used by
previous versions of `dnstli` and the `dnstli_scgi_server` script has been
updated to invoke the uWSGI server in SCGI mode in order to allow smooth
upgrades from previous versions of `dnstli` without changing the `dnstli`
startup scripts or the nginx server configuration, it is recommended to migrate
to the faster, more commonly used uwsgi protocol and the native uWSGI server,
described below, which will also allow full customization of uWSGI server
parameters via an `.ini` file. However, this requires changes to how `dnstli`
is started up and to how the frontend nginx server is configured. These changes
are recommended; the `dnstli_scgi_server` script may be removed in a future
`dnstli` release.

If using the `dnstli` Web UI server, `dnstli` 3.0.0 requires a simultaneous
upgrade to `dnstui` 1.0.0, due to bug fixes that require coordinated client-
and server- side changes.

The authentication and lookup logs generated by `dnstli` as of version 3.0.0 are
now encoded using JSON. These logs are substantially easier to parse than the ad
hoc text format used in previous versions of `dnstli`. For instance, they can be
imported into existing off-the-shelf tools with JSON log import support. The
`dnstli_report` utility shipped in the `dnstli` distribution has been updated to
read both the old and new log formats.

[uWSGI application server]: https://uwsgi-docs.readthedocs.org/en/latest/

Installing uWSGI
----------------

It is recommended to run a recent version of the uWSGI application server.
`dnstli` 3.0.0 was tested with uWSGI 2.0.10. uWSGI must be built with Python
and SCGI support, and uWSGI's `uwsgidecorators` Python module must be
installed.

On Debian-based systems, an `fsi-uwsgi` package may be available from a
Farsight apt repository, which contains a monolithic build of the uWSGI server
bundled with the Python `uwsgidecorators` module. This package should be used
in preference to packages that may be available from the Debian.org or
Ubuntu.com repositories.

Continuing to use dnstli\_scgi\_server and the SCGI protocol
------------------------------------------------------------

**NOTE**: ***This is NOT the preferred upgrade path.*** *See the following
section instead if you want to migrate to the new uwsgi protocol server, which
is preferred. The only reason to use the instructions in this section is to
avoid updating the `dnstli` startup script and nginx configuration. Only one of
these upgrade paths should be performed.*

The `dnstli_scgi_server` script has been updated in `dnstli` 3.0.0 to invoke
the uWSGI server in SCGI mode. If you want to continue using
`dnstli_scgi_server`, which requires no further changes, simply restart the
`dnstli` service(s) after installing `dnstli` 3.0.0.

The `runit` service supervisor is typically used to manage `dnstli_scgi_server`
instances. The service name used for `dnstli_scgi_server` service instances may
vary; a list of system-wide runit services may be obtained by running the
following command:

    sv status /etc/service/*

Run `sv force-restart <SERVICE-NAME>` for each service instance, substituting
`<SERVICE-NAME>` for the `dnstli` instance's service name, in order to restart
`dnstli`.

You should now be running dnstli 3.0.0 in SCGI mode, with no changes to your
existing frontend nginx server configuration.

Migrating to uWSGI and the uwsgi protocol
-----------------------------------------

**NOTE**: ***This is the preferred upgrade path.*** *See the previous section
instead if you want to continue using the old SCGI protocol server. Only one of
the these upgrade paths should be performed.*

Migrating from the old `dnstli_scgi_server` script to the native `uwsgi`-based
service offers the full flexibility of the uWSGI server. See the [uWSGI
documentation] for details.

[uWSGI documentation]: http://uwsgi-docs.readthedocs.org/en/latest/

The example files referenced below are included in the `examples/uwsgi/`
directory in the `dnstli` 3.0.0 distribution tarball and git repository. If
using the `dnstli` Debian package available from a Farsight apt repository,
these files are located in the `/usr/share/doc/dnstli/examples/uwsgi/`
directory.

First, install `dnstli` 3.0.0, either from source or from a binary package.

Copy the `dnstli_api.ini` example uWSGI config file from the `examples/uwsgi/`
directory into the `dnstli` API server's runit service directory.

Copy the `run_api` script from the `examples/uwsgi/` directory into the
`dnstli` server's runit service directory. Rename this file to `run`,
overwriting the `run` file from a previous installation of `dnstli`.

Edit the nginx server config for the `dnstli` API server. Your existing
configuration should have a `location` block for the `/lookup` path that looks
like:

```
    location /lookup {
        scgi_buffering off;
        scgi_pass unix:/var/run/dnstli/scgi-api.socket;
        include scgi_params;
    }
```

Replace these lines with the following:

```
    location /lookup {
        uwsgi_buffering off;
        uwsgi_pass unix:/run/dnstli/uwsgi-api.socket;
        include uwsgi_params;
    }
```

Restart both nginx and the dnstli API runit service.

If you are using the `dnstli` Web UI server, migration is similar to the above
instructions, but substitute "`web`" for "`api`". That is, the example uWSGI
config file is named `dnstli_web.ini`, the example runit run script is named
`run_web`, and the uwsgi socket in the nginx server config is named
`/run/dnstli/uwsgi-web.socket`.

**NOTE**: Rather than altering the runit service directory in place as described
above, you may want to create new runit services using the new run scripts in
parallel with the old services. Since the new configuration uses a new unix
socket path, the old and new services can be run simultaneously without
conflicting during the migration.
